@@ -22,17 +22,17 @@ class IEmbeddedPage(Interface):
     )
 
     before = RichText(
-        title=_(u"Show Before"),
+        title=_("Show Before"),
         required=False,
     )
 
     after = RichText(
-        title=_(u"Show After"),
+        title=_("Show After"),
         required=False,
     )
 
     form.widget(disable_right_portlet=SingleCheckBoxFieldWidget)
     disable_right_portlet = schema.Bool(
-        title=_(u"Disable Right Portlet"),
+        title=_("Disable Right Portlet"),
         required=False,
     )
